/*!
 * Color mode toggler for Bootstrap's docs (https://getbootstrap.com/)
 * Copyright 2011-2022 The Bootstrap Authors
 * Licensed under the Creative Commons Attribution 3.0 Unported License.
 */

(() => {
    'use strict'

    const storedTheme = localStorage.getItem('theme')

    const getPreferredTheme = () => {
        if (storedTheme) {
            return storedTheme
        }

        return window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light'
    }

    const setTheme = function(theme) {
        if (theme === 'auto' && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.setAttribute('data-bs-theme', 'dark')
            set_captcha_theme('dark', 0)
        } else {
            document.documentElement.setAttribute('data-bs-theme', theme)
            set_captcha_theme(theme, 0)
        }
    }

    setTheme(getPreferredTheme())

    const showActiveTheme = theme => {
        // const activeThemeIcon = document.querySelector('.theme-icon-active use')
        // const svgOfActiveBtn = btnToActive.querySelector('svg use').getAttribute('href')
        const btnToActive = document.querySelector(`[data-bs-theme-value="${theme}"]`)

        document.querySelectorAll('[data-bs-theme-value]').forEach(element => {
            element.classList.remove('active')
        })

        btnToActive.classList.add('active')
        // activeThemeIcon.setAttribute('href', svgOfActiveBtn)
    }

    window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', () => {
        if (storedTheme !== 'light' || storedTheme !== 'dark') {
            setTheme(getPreferredTheme())
        }
    })

    window.addEventListener('DOMContentLoaded', () => {
        showActiveTheme(getPreferredTheme())

        document.querySelectorAll('[data-bs-theme-value]')
            .forEach(toggle => {
                toggle.addEventListener('click', () => {
                    const theme = toggle.getAttribute('data-bs-theme-value')
                    localStorage.setItem('theme', theme)
                    setTheme(theme)
                    showActiveTheme(theme)
                })
            })
    })
})()

function set_captcha_theme(theme, set_try) {
    var captchaDiv = document.getElementById("id_captcha");

    if (captchaDiv) {
        console.log("Set the theme on try" + set_try)
        if (theme == 'dark') {
            captchaDiv.classList.add("dark");
        } else {
            captchaDiv.classList.remove("dark");
        }
    }
};